Welcome to Data Portal Explorer's documentation!
================================================

Data Portal Explorer is a Python library, and command line tool, to harvest data from
CKAN_ data repositories, using the ckanapi_ library. 

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   contributing
   history
..   modules

Indices and tables
==================
* :ref:`genindex`
* :ref:`search`

.. * :ref:`modindex`

.. _CKAN: https://ckan.org/
.. _ckanapi: https://github.com/ckan/ckanapi
